[![PyPI version](https://badge.fury.io/py/sos-scala.svg)](https://badge.fury.io/py/sos-scala)

# sos-scala
SoS extension for Scala. Please refer to the [SoS homepage](http://vatlab.github.io/SOS) for more information.
